/*******************************************************************************
* File Name: Ambient.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Ambient.h"


/*******************************************************************************
* Function Name: Ambient_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void Ambient_Write(uint8 value) 
{
    uint8 staticBits = (Ambient_DR & (uint8)(~Ambient_MASK));
    Ambient_DR = staticBits | ((uint8)(value << Ambient_SHIFT) & Ambient_MASK);
}


/*******************************************************************************
* Function Name: Ambient_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  Ambient_DM_STRONG     Strong Drive 
*  Ambient_DM_OD_HI      Open Drain, Drives High 
*  Ambient_DM_OD_LO      Open Drain, Drives Low 
*  Ambient_DM_RES_UP     Resistive Pull Up 
*  Ambient_DM_RES_DWN    Resistive Pull Down 
*  Ambient_DM_RES_UPDWN  Resistive Pull Up/Down 
*  Ambient_DM_DIG_HIZ    High Impedance Digital 
*  Ambient_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void Ambient_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(Ambient_0, mode);
}


/*******************************************************************************
* Function Name: Ambient_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Ambient_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Ambient_Read(void) 
{
    return (Ambient_PS & Ambient_MASK) >> Ambient_SHIFT;
}


/*******************************************************************************
* Function Name: Ambient_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Ambient_ReadDataReg(void) 
{
    return (Ambient_DR & Ambient_MASK) >> Ambient_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Ambient_INTSTAT) 

    /*******************************************************************************
    * Function Name: Ambient_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Ambient_ClearInterrupt(void) 
    {
        return (Ambient_INTSTAT & Ambient_MASK) >> Ambient_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
