/*******************************************************************************
* File Name: EF.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "EF.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 EF__PORT == 15 && ((EF__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: EF_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void EF_Write(uint8 value) 
{
    uint8 staticBits = (EF_DR & (uint8)(~EF_MASK));
    EF_DR = staticBits | ((uint8)(value << EF_SHIFT) & EF_MASK);
}


/*******************************************************************************
* Function Name: EF_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  EF_DM_STRONG     Strong Drive 
*  EF_DM_OD_HI      Open Drain, Drives High 
*  EF_DM_OD_LO      Open Drain, Drives Low 
*  EF_DM_RES_UP     Resistive Pull Up 
*  EF_DM_RES_DWN    Resistive Pull Down 
*  EF_DM_RES_UPDWN  Resistive Pull Up/Down 
*  EF_DM_DIG_HIZ    High Impedance Digital 
*  EF_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void EF_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(EF_0, mode);
}


/*******************************************************************************
* Function Name: EF_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro EF_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 EF_Read(void) 
{
    return (EF_PS & EF_MASK) >> EF_SHIFT;
}


/*******************************************************************************
* Function Name: EF_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 EF_ReadDataReg(void) 
{
    return (EF_DR & EF_MASK) >> EF_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(EF_INTSTAT) 

    /*******************************************************************************
    * Function Name: EF_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 EF_ClearInterrupt(void) 
    {
        return (EF_INTSTAT & EF_MASK) >> EF_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
