/*******************************************************************************
* File Name: IP_VTG.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "IP_VTG.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 IP_VTG__PORT == 15 && ((IP_VTG__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: IP_VTG_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void IP_VTG_Write(uint8 value) 
{
    uint8 staticBits = (IP_VTG_DR & (uint8)(~IP_VTG_MASK));
    IP_VTG_DR = staticBits | ((uint8)(value << IP_VTG_SHIFT) & IP_VTG_MASK);
}


/*******************************************************************************
* Function Name: IP_VTG_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  IP_VTG_DM_STRONG     Strong Drive 
*  IP_VTG_DM_OD_HI      Open Drain, Drives High 
*  IP_VTG_DM_OD_LO      Open Drain, Drives Low 
*  IP_VTG_DM_RES_UP     Resistive Pull Up 
*  IP_VTG_DM_RES_DWN    Resistive Pull Down 
*  IP_VTG_DM_RES_UPDWN  Resistive Pull Up/Down 
*  IP_VTG_DM_DIG_HIZ    High Impedance Digital 
*  IP_VTG_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void IP_VTG_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(IP_VTG_0, mode);
}


/*******************************************************************************
* Function Name: IP_VTG_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro IP_VTG_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 IP_VTG_Read(void) 
{
    return (IP_VTG_PS & IP_VTG_MASK) >> IP_VTG_SHIFT;
}


/*******************************************************************************
* Function Name: IP_VTG_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 IP_VTG_ReadDataReg(void) 
{
    return (IP_VTG_DR & IP_VTG_MASK) >> IP_VTG_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(IP_VTG_INTSTAT) 

    /*******************************************************************************
    * Function Name: IP_VTG_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 IP_VTG_ClearInterrupt(void) 
    {
        return (IP_VTG_INTSTAT & IP_VTG_MASK) >> IP_VTG_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
