/*******************************************************************************
* File Name: relay.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "relay.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 relay__PORT == 15 && ((relay__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: relay_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void relay_Write(uint8 value) 
{
    uint8 staticBits = (relay_DR & (uint8)(~relay_MASK));
    relay_DR = staticBits | ((uint8)(value << relay_SHIFT) & relay_MASK);
}


/*******************************************************************************
* Function Name: relay_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  relay_DM_STRONG     Strong Drive 
*  relay_DM_OD_HI      Open Drain, Drives High 
*  relay_DM_OD_LO      Open Drain, Drives Low 
*  relay_DM_RES_UP     Resistive Pull Up 
*  relay_DM_RES_DWN    Resistive Pull Down 
*  relay_DM_RES_UPDWN  Resistive Pull Up/Down 
*  relay_DM_DIG_HIZ    High Impedance Digital 
*  relay_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void relay_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(relay_0, mode);
	CyPins_SetPinDriveMode(relay_1, mode);
	CyPins_SetPinDriveMode(relay_2, mode);
}


/*******************************************************************************
* Function Name: relay_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro relay_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 relay_Read(void) 
{
    return (relay_PS & relay_MASK) >> relay_SHIFT;
}


/*******************************************************************************
* Function Name: relay_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 relay_ReadDataReg(void) 
{
    return (relay_DR & relay_MASK) >> relay_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(relay_INTSTAT) 

    /*******************************************************************************
    * Function Name: relay_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 relay_ClearInterrupt(void) 
    {
        return (relay_INTSTAT & relay_MASK) >> relay_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
