/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/

//header files
#include <device.h>


/***************************************CONSTANTS******************************************************/
//system_flags
#define 	Sample_Done		0x01
#define  	Zero_Done   	0x02
#define		Span_Done		0x04
#define		Sensor_Ok		0x08
#define		Sensor_Drift	0x10
#define     Low_Voltage     0x20
#define     Sensor_Over     0x40
#define 	Blink			0x80
//Screens
#define Main_Scr    1
#define K1_Scr      2
#define K2_Scr      3
#define ss_detect_Scr   4
#define Main_Scr1   5

//Keys
#define K1     1
#define K2     2

//for lcd
#define 	LCD_RS  		0x01
#define		LCD_RW 			0x02
#define		LCD_EN			0x04

/***************************************************Function Protos*******************************************************/
void lcd_setup(void);
void wait(unsigned long ticks);
void rom2ram(char const *lcd_temp, unsigned char i);
void lcd1_data(unsigned char data1);
void lcd1_command(unsigned char command);
void update_lcd(void);

void Read_ADC(void);

//protos for rtc
void read_rtc(void);
void write_rtc(void);
void get_clock(void);
unsigned char pbcd2bin (unsigned char );
unsigned char bin2pbcd (unsigned char );

//structures

//structure for RTC
struct
{
    unsigned char sec;
    unsigned char mins;
    unsigned char hours;
    unsigned char day;
    unsigned char date;
    unsigned char month;
    unsigned char year;
    unsigned char ctrl;
}RTC_RD,RTC_WR;




/*********************************************Global variables*****************************************************************/

char Scr_No, Key_val, Key_pressed,System_Flags;
//bit Sensor_Present;
volatile uint8 	lcd_buf[256];

//adc_varriable
volatile signed long   	ADC_Value;
volatile unsigned int  	ADC_Cntr;
volatile signed int     Reading,Reading1;

signed int num_1=0;
unsigned int temp_char=0,rtc_time;
unsigned char   ReadAddress_c;
    



/*******************************************************************************************************************
Define interrupt service routine and allocate VECTOR HANDLER
***************************************************************************************************************************/

CY_ISR(ADC_HANDLER)
{
    //RUNNING @2000Hz
    Read_ADC();
//    House_keeping():    
}

void delay(unsigned long ticks)
{
  while(ticks--);
}

//************************************************************************
//very short delay for lcd
void wait(unsigned long ticks)
{
  while(ticks--);
}

void lcd1_data(unsigned char data1)
{
  unsigned char temp;
  temp = data1;
  
  wait(100);
  OLED_D_Write(temp);
  wait(2);
  OLED_CTRL_Write(LCD_RS);
  wait(2);
  OLED_CTRL_Write(LCD_RS | LCD_EN);
  wait(2);
  OLED_CTRL_Write(LCD_RS);  
}

// write command 
void lcd1_command(unsigned char command)
{
 
  unsigned char temp;
  temp = command;
  
  wait(100);
  OLED_D_Write(temp);
  wait(2);
  OLED_CTRL_Write(0);
  wait(2);
  OLED_CTRL_Write(LCD_EN);
  wait(2);
  OLED_CTRL_Write(0);   
}  
//************************************************************************
// update lcd module
void update_lcd(void)
{
  unsigned char i;
  
  lcd1_command(0x80);     //send first 16 characters of lcd buffer to 1st line 
  for(i = 0;i < 8; i++)
  {
    lcd1_data(lcd_buf[i]);
  }	
	
  lcd1_command(0xc0);     //send second 16 characters of lcd buffer to 2nd line 
  for(i = 8;i < 16; i++)
  {
    lcd1_data(lcd_buf[i]);
  }	
}

// lcd initialize to 16 X 2
void lcd_setup(void)
{ 
  wait(0x1ffff);
  lcd1_command(0x30);
  wait(0x1ffff);
  lcd1_command(0x30);
  wait(10000);
  lcd1_command(0x30);
  wait(10000);
  lcd1_command(0x38);
  wait(10000);
  lcd1_command(0x08);
  wait(10000);
  lcd1_command(0x01);
  wait(10000);
  lcd1_command(0x06);
  wait(10000);
  lcd1_command(0x0c);
  wait(10000);
  rom2ram("        ",0);
  rom2ram("        ",8);
  update_lcd();
}



//************************************************************************
//copy string from rom to ram
void rom2ram(char const *lcd_temp, unsigned char i)
{  
  while(*lcd_temp != 0)
  lcd_buf[i++] = *lcd_temp++;
}
//************************************************************************
void Disp_Num(signed int Number, unsigned char Pos, unsigned char Dp, unsigned char Digits)
{   
    unsigned char e[6];
    
    if(Number < 0)
    {
        Number = ~Number + 1;
        lcd_buf[Pos++] = '-';
    }
    else
        lcd_buf[Pos++] = ' ';
        
    e[0] = e[1] = e[2] = e[3] = e[4] = e[5] = 0;
    
    e[0] = ((Number%1000000) / 100000);
    e[1] = ((Number%100000) / 10000);
    e[2] = ((Number%10000) / 1000);
    e[3] = ((Number%1000) / 100);
    e[4] = ((Number%100) / 10);
    e[5] = ((Number%10) / 1);
    
    if(Digits >= 6)
    {
        lcd_buf[Pos++]  =   e[0] + 0x30;
        
        if(Dp == 5)
            lcd_buf[Pos++] = '.';
    }    
    if(Digits >= 5)
    {
        lcd_buf[Pos++]  =   e[1] + 0x30;
        
        if(Dp == 4)
            lcd_buf[Pos++] = '.';
    }    
    if(Digits >= 4)
    {
        lcd_buf[Pos++]  =   e[2] + 0x30;
        
        if(Dp == 3)
            lcd_buf[Pos++] = '.';
    }    
    if(Digits >= 3)
    {
        lcd_buf[Pos++]  =   e[3] + '0';
        
        if(Dp == 2)
            lcd_buf[Pos++] = '.';
    }        
    if(Digits >= 2)
    {
        lcd_buf[Pos++]  =   e[4] + '0';
        
        if(Dp == 1)
            lcd_buf[Pos++] = '.';
    }    
    lcd_buf[Pos++]  =   e[5] + '0';
}
//************************************************************************
void Fill_Display(void)
{
    
    
    rom2ram("        ", 0);
    rom2ram("        ", 8);
    
    if(Scr_No == Main_Scr)
    {
        rom2ram("UNIPHOS ",0);
        rom2ram(" 500DT  ",8);
    }
    else if(Scr_No == Main_Scr1)
    {
        rom2ram("  TIME  ",0);
        //rom2ram("    ", 8);
        Disp_Num(RTC_RD.hours, 7, 0, 2);
        
        Disp_Num(RTC_RD.mins, 10, 0, 2);
        rom2ram(":",10);
        
        Disp_Num(RTC_RD.sec, 13, 0, 2);
        rom2ram(":",13);
    }
    
    else if(Scr_No == K1_Scr)
    {
        rom2ram("UNIPHOS ",0);
        rom2ram("        ",8);
       // Disp_Num((ADC_CountsTo_mVolts(Reading)),8,0,6);
        Disp_Num(num_1, 8, 0, 4);
    }
    
    else if(Scr_No == K2_Scr)
    {
        rom2ram("UNIPHOS ",0);
        rom2ram("        ",8);
        Disp_Num(num_1, 8, 0, 4);
    }  
    else if(Scr_No == ss_detect_Scr)
    {
        rom2ram("SS DETCT",0);
        rom2ram("        ",8);
        Disp_Num(Reading1, 8, 0, 6);
    }     
  update_lcd();
}

void Key_Check(void)
{
    Key_val = Keys_Read(); 
    Key_val &= 0x03;
    
    if((Key_val & 0x02) == 0x00)
    {
        Key_pressed = K2;
    }
    else if((Key_val & 0x01) == 0x00)
    {
        Key_pressed = K1;
    }
    
    //if(Scr_No == Main_Scr)
    //{
        if(Key_pressed == K1)
            Scr_No = Main_Scr1;
        
        else if(Key_pressed == K2)
            Scr_No = K2_Scr;
        
    //    else
    //        Scr_No = Main_Scr;
    //}
    
    Key_pressed = 0x03;
    Key_val = 0x03;
}

void Read_ADC(void)
{
    unsigned int Reading1;
    
    ADC_Value += ADC_GetResult16();
    ADC_Cntr++;
    
    if(ADC_Cntr == 4)   
    {
           ADC_Value = 0;
    }
    else if(ADC_Cntr == 260)    //256+4
    {
        ADC_Value >>= 8;       
        Reading1 = (int)ADC_Value; 
        Reading = (Reading1 % 10000)/1;       
        ADC_Value = 0;
        ADC_Cntr = 0;
    }
    
    System_Flags |= Sample_Done;
}

void SetUp_Variables(void)
{
    // variable initialization
    Key_pressed = 0;
    Key_val = 0x03;
    
    ADC_Cntr = 0;
    
    //Sensor_Present = 1;
    
    //screen initialization
    Scr_No = Main_Scr1;      
    
    //Port lines initializations
    
    
}
/*
void Get_Value(void)
{
    if(System_Flag & Sample_Done)
    {
        System_Flag &= ~Sample_Done; 
        
        Reading = ADC_Value;
        
    }
}*/
//************************************************************************
//RTC ROUTINE
void read_rtc(void)
{
  unsigned char buff[16];

  ReadAddress_c = 0x00;
  
  // Do an I2C write operation to set the EEPROM internal address
  I2C_MasterWriteBuf(0x68, &ReadAddress_c, 1, I2C_MODE_COMPLETE_XFER);
  delay(5000);
  I2C_MasterReadBuf(0x68, &buff[0], 7, I2C_MODE_COMPLETE_XFER);

  RTC_RD.sec = pbcd2bin(buff[0] & 0x7f);
  RTC_RD.mins = pbcd2bin(buff[1] & 0x7f);
  RTC_RD.hours = pbcd2bin(buff[2] & 0x3f);
  RTC_RD.day = buff[3] & 0x07;
  RTC_RD.date = pbcd2bin(buff[4] & 0x3f);
  RTC_RD.month = pbcd2bin(buff[5] & 0x1f);
  RTC_RD.year = pbcd2bin(buff[6]);
}
//************************************************************************
void write_rtc(void)
{  
  unsigned char buff[16];
  
  buff[0] = 0;
  buff[1] = 0;
  buff[2] = bin2pbcd(RTC_WR.mins);
  buff[3] = bin2pbcd(RTC_WR.hours);
  buff[4] = bin2pbcd(RTC_WR.day);
  buff[5] = bin2pbcd(RTC_WR.date);
  buff[6] = bin2pbcd(RTC_WR.month);
  buff[7] = bin2pbcd(RTC_WR.year);
  
  /* Send the contents of the data in txBuffer */;
  I2C_MasterWriteBuf(0x68, buff, 8, I2C_MODE_COMPLETE_XFER);
  
  delay(5000);
}
//************************************************************************
unsigned char bin2pbcd (unsigned char bin_num)
{
  char high = 0;
 
  while (bin_num >= 10)                						 // Count tens
  {
    high++;
    bin_num -= 10;
  }  
  high = high << 4;
  high &= 0xf0;
  bin_num &= 0x0f;
  high |= bin_num;
  return high;
}	
//************************************************************************
unsigned char pbcd2bin (unsigned char pbcd_num)
{
  unsigned char bin_num;
  
  bin_num = pbcd_num & 0x0f;
  pbcd_num = pbcd_num >> 4;
  bin_num += pbcd_num * 10;
  return bin_num;
} 
//************************************************************************

//************************************************************************

void get_clock(void)
{ 
    if(rtc_time <= 1)
    {
        rtc_time = 100;
        read_rtc();
    }
}

int main()
{
 
    CyGlobalIntEnable; /* Enable global interrupts. */
    I2C_Start();
    
    /* Place your initialization/startup code here (e.g. MyInst_Start()) */
    lcd_setup();
    SetUp_Variables();
    
    
    for(;;)
    {   
        Fill_Display();        
        Key_Check();
        get_clock();
        
        if(rtc_time != 0)
            rtc_time--;
        
        temp_char++;
        
        if(temp_char >2000)
        {
            temp_char = 0;
            num_1++;
            
            if(num_1 > 999)
                num_1 = 0;
        }      

                
    }
}

/* [] END OF FILE */
